//+------------------------------------------------------------------+
//|                                                   FiboPiv_v1.mq4 |
//|                                                          Kalenzo |
//|                                      bartlomiej.gorski@gmail.com |
//+------------------------------------------------------------------+
#property copyright "Kalenzo"
#property link      "bartlomiej.gorski@gmail.com"

/*--------------------------------------------------------------------
PriorDayFiboPivots:  

This version enhances the indicator.  The user can select individual
line colors, lines style, labels color, font size, bold font, move
the line labels left & right on the chart, and choose whether or not
to show the prior day O, H, L, C data.  It is off by default, but if 
chosen, it will appear on the line directly below the data for the
current day, and in the same format.

                                     - Traderathome, November 9,2008
--------------------------------------------------------------------*/
#property indicator_chart_window

extern int   Solid_2Dash_3Dot_4DashDotDot = 1;  //default=1=Solid
extern color Fib_R3 = ForestGreen;
extern color Fib_R2 = Green;
extern color Fib_R1 = DarkGreen;
extern color Fib_PV = DarkViolet;
extern color Fib_S1 = Maroon;
extern color Fib_S2 = FireBrick;
extern color Fib_S3 = Crimson;
extern color Color_Labels = Black;
extern int   Slide_Labels = 20;  //+ to move left, - to move right
extern int   Size_Font = 9;      //+ to increase size
extern bool  Bold_Font = false;  //true = bold turned on
extern bool  PriorDay_OHLC_Data = false; //true = display data

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   ObjectDelete("S1");
   ObjectDelete("S2");
   ObjectDelete("S3");
   ObjectDelete("R1");
   ObjectDelete("R2");
   ObjectDelete("R3");
   ObjectDelete("PIVOT");
   ObjectDelete("Fibonacci  S1");
   ObjectDelete("Fibonacci  S2");
   ObjectDelete("Fibonacci  S3");
   ObjectDelete("Fibonacci  PV");
   ObjectDelete("Fibonacci  R1");
   ObjectDelete("Fibonacci  R2");
   ObjectDelete("Fibonacci  R3");
   Comment(" ");
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
double rates[1][6],yesterday_open,yesterday_high,yesterday_low,yesterday_close;
ArrayCopyRates(rates, Symbol(), PERIOD_D1);
if(DayOfWeek() == 1)
{
   if(TimeDayOfWeek(iTime(Symbol(),PERIOD_D1,1)) == 5)
   {
       yesterday_open = rates[1][1];
       yesterday_high = rates[1][3];
       yesterday_low = rates[1][2];
       yesterday_close = rates[1][4];
   }
   else
   {
      for(int d = 5;d>=0;d--)
      {
         if(TimeDayOfWeek(iTime(Symbol(),PERIOD_D1,d)) == 5)
         {
             yesterday_open = rates[d][1];
             yesterday_high = rates[d][3];
             yesterday_low = rates[d][2];
             yesterday_close = rates[d][4];
         }        
      }  
   }
}
else
{
    yesterday_open = rates[1][1];
    yesterday_high = rates[1][3];
    yesterday_low = rates[1][2];
    yesterday_close = rates[1][4];
}
//---- Calculate Pivots
if (PriorDay_OHLC_Data == true)
    {Comment("PRIORDAY  ",yesterday_open," ",yesterday_high," ",yesterday_low, " ",yesterday_close);}
double R = yesterday_high - yesterday_low;//range
double p = (yesterday_high + yesterday_low + yesterday_close)/3;// Standard Pivot
double r3 = p + (R * 1.000);
double r2 = p + (R * 0.618);
double r1 = p + (R * 0.382);
double s1 = p - (R * 0.382);
double s2 = p - (R * 0.618);
double s3 = p - (R * 1.000);
drawLine(r3,"R3", Fib_R3,0);
drawLabel("Fibonacci  R3",r3,Color_Labels);
drawLine(r2,"R2", Fib_R2,0);
drawLabel("Fibonacci  R2",r2,Color_Labels);
drawLine(r1,"R1", Fib_R1,0);
drawLabel("Fibonacci  R1",r1,Color_Labels);
drawLine(p,"PIVOT",Fib_PV,0);
drawLabel("Fibonacci  PV", p,Color_Labels);
drawLine(s1,"S1",Fib_S1,0);
drawLabel("Fibonacci  S1",s1,Color_Labels);
drawLine(s2,"S2",Fib_S2,0);
drawLabel("Fibonacci  S2",s2,Color_Labels);
drawLine(s3,"S3",Fib_S3,0);
drawLabel("Fibonacci  S3",s3,Color_Labels);
//----
   return(0);
  }
//+------------------------------------------------------------------+
void drawLabel(string name,double lvl,color Color)
{
    if(ObjectFind(name) != 0)
    {
    string Font = "Arial"; int ml = Slide_Labels;
    if (Bold_Font == true) Font = "Arial Bold";
        ObjectCreate(name, OBJ_TEXT, 0, Time[ml], lvl);
        ObjectSetText(name, name, Size_Font, Font, EMPTY);
        ObjectSet(name, OBJPROP_COLOR, Color);
    }
    else
    {
        ObjectMove(name, 0, Time[ml], lvl);
    }
}
void drawLine(double lvl,string name, color Col,int type)
{
    int a= Solid_2Dash_3Dot_4DashDotDot;
    if(ObjectFind(name) != 0)
         {
            ObjectCreate(name, OBJ_HLINE, 0, Time[0], lvl,Time[0],lvl);            
            if (a == 1)          
            ObjectSet(name, OBJPROP_STYLE, STYLE_SOLID); 
            if (a == 2)            
            ObjectSet(name, OBJPROP_STYLE, STYLE_DASH);
            if (a == 3)
            ObjectSet(name, OBJPROP_STYLE, STYLE_DOT);
            if (a == 4)
            ObjectSet(name, OBJPROP_STYLE, STYLE_DASHDOTDOT);   
            ObjectSet(name, OBJPROP_COLOR, Col);        
            ObjectSet(name, OBJPROP_WIDTH,1);           
         }
         else
         {
            ObjectDelete(name);
            ObjectCreate(name, OBJ_HLINE, 0, Time[0], lvl,Time[0],lvl);           
            if (a == 1)            
            ObjectSet(name, OBJPROP_STYLE, STYLE_SOLID);            
            if (a == 2)
            ObjectSet(name, OBJPROP_STYLE, STYLE_DASH);
            if (a == 3)          
            ObjectSet(name, OBJPROP_STYLE, STYLE_DOT); 
            if (a == 4)
            ObjectSet(name, OBJPROP_STYLE, STYLE_DASHDOTDOT); 
            ObjectSet(name, OBJPROP_COLOR, Col);        
            ObjectSet(name,OBJPROP_WIDTH,1);
          
         }
}
//--------------------- End of Program ---------------------------------

